/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/**
 * nsIXPCScriptNotify is an interface that is used for notifying a client
 * that the script has been evaluated by XPConnect. if any JSContext in our 
 * JSRuntime has set the JSOPTION_PRIVATE_IS_NSISUPPORTS option and the 
 * private context supports nsIXPCScriptNotify then this method is invoked
 */


#include "nsISupports.idl"

[uuid(13aceb15-812a-476a-9326-2adc00250b76)]
interface nsIXPCScriptNotify : nsISupports
{
    /**
     * Method invoked when a script has been executed by XPConnect
     */
    void ScriptExecuted();
};

