/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

/**
 * In general, DOM methods return specific error values in ordinary
 * processing situations, such as out-of-bound errors.
 * However, DOM operations can raise exceptions in "exceptional"
 * circumstances, i.e., when an operation is impossible to perform
 * (either for logical reasons, because data is lost, or because the
 * implementation has become unstable)
 *
 * For more information on this interface please see
 * http://dvcs.w3.org/hg/domcore/raw-file/tip/Overview.html#domexception
 */

[scriptable, uuid(5bd766d3-57a9-4833-995d-dbe21da29595)]
interface nsIDOMDOMException : nsISupports
{
  const unsigned short      INDEX_SIZE_ERR                 = 1;
  const unsigned short      DOMSTRING_SIZE_ERR             = 2; // historical
  const unsigned short      HIERARCHY_REQUEST_ERR          = 3;
  const unsigned short      WRONG_DOCUMENT_ERR             = 4;
  const unsigned short      INVALID_CHARACTER_ERR          = 5;
  const unsigned short      NO_DATA_ALLOWED_ERR            = 6; // historical
  const unsigned short      NO_MODIFICATION_ALLOWED_ERR    = 7;
  const unsigned short      NOT_FOUND_ERR                  = 8;
  const unsigned short      NOT_SUPPORTED_ERR              = 9;
  const unsigned short      INUSE_ATTRIBUTE_ERR            = 10; // historical
  const unsigned short      INVALID_STATE_ERR              = 11;
  const unsigned short      SYNTAX_ERR                     = 12;
  const unsigned short      INVALID_MODIFICATION_ERR       = 13;
  const unsigned short      NAMESPACE_ERR                  = 14;
  const unsigned short      INVALID_ACCESS_ERR             = 15;
  const unsigned short      VALIDATION_ERR                 = 16; // historical
  const unsigned short      TYPE_MISMATCH_ERR              = 17;
  const unsigned short      SECURITY_ERR                   = 18;
  const unsigned short      NETWORK_ERR                    = 19;
  const unsigned short      ABORT_ERR                      = 20;
  const unsigned short      URL_MISMATCH_ERR               = 21;
  const unsigned short      QUOTA_EXCEEDED_ERR             = 22;
  const unsigned short      TIMEOUT_ERR                    = 23;
  const unsigned short      INVALID_NODE_TYPE_ERR          = 24;
  const unsigned short      DATA_CLONE_ERR                 = 25;

  readonly attribute unsigned short   code;
};

